==> onnx-tf-1.1-py36_0.tar.bz2: Lib/site-packages/onnx_tf/opset_version.py <==
backend_opset_version = {
    'ATen': [],
    'Abs': [1, 6],
    'Add': [1, 6],
    'Affine': [],
    'And': [1],
    'ArgMax': [1],
    'ArgMin': [1],
    'AveragePool': [1],
    'BatchNormalization': [1, 6],
    'Cast': [1],
    'Ceil': [1, 6],
    'Clip': [1, 6],
    'Concat': [1, 4],
    'Constant': [1],
    'ConstantFill': [1],
    'Conv': [1],
    'ConvTranspose': [1],
    'Crop': [],
    'DepthToSpace': [1],
    'Div': [1, 6],
    'Dropout': [1, 6],
    'Elu': [1, 6],
    'Equal': [1],
    'Exp': [1, 6],
    'FC': [],
    'Flatten': [1],
    'Floor': [1, 6],
    'GRU': [],
    'GRUUnit': [],
    'Gather': [1],
    'Gemm': [1, 6],
    'GivenTensorFill': [],
    'GlobalAveragePool': [1],
    'GlobalLpPool': [1, 2],
    'GlobalMaxPool': [1],
    'Greater': [1],
    'HardSigmoid': [1, 6],
    'Hardmax': [1],
    'Identity': [1],
    'If': [],
    'ImageScaler': [],
    'InstanceNormalization': [],
    'LRN': [1],
    'LSTM': [1],
    'LeakyRelu': [1, 6],
    'Less': [1],
    'Log': [1, 6],
    'LogSoftmax': [1],
    'Loop': [],
    'LoopIndexTensor': [],
    'LpNormalization': [1],
    'LpPool': [],
    'MatMul': [1],
    'Max': [1, 6],
    'MaxPool': [1],
    'MaxRoiPool': [],
    'Mean': [1, 6],
    'MeanVarianceNormalization': [],
    'Min': [1, 6],
    'Mul': [1, 6],
    'Neg': [1, 6],
    'Not': [1],
    'Or': [1],
    'PRelu': [1, 6],
    'Pad': [1, 2],
    'ParametricSoftplus': [],
    'Pow': [1],
    'RNN': [],
    'RandomNormal': [1],
    'RandomNormalLike': [1],
    'RandomUniform': [1],
    'RandomUniformLike': [1],
    'Reciprocal': [1, 6],
    'ReduceL1': [1],
    'ReduceL2': [],
    'ReduceLogSum': [1],
    'ReduceLogSumExp': [1],
    'ReduceMax': [1],
    'ReduceMean': [1],
    'ReduceMin': [1],
    'ReduceProd': [1],
    'ReduceSum': [1],
    'ReduceSumSquare': [1],
    'Relu': [1, 6],
    'Reshape': [1, 5],
    'Scale': [],
    'ScaledTanh': [],
    'Selu': [1, 6],
    'Shape': [1],
    'Sigmoid': [1, 6],
    'Size': [1],
    'Slice': [1],
    'Softmax': [1],
    'Softplus': [1],
    'Softsign': [1],
    'SpaceToDepth': [1],
    'Split': [1, 2],
    'Sqrt': [1, 6],
    'Squeeze': [1],
    'Sub': [1, 6],
    'Sum': [1, 6],
    'Tanh': [1, 6],
    'ThresholdedRelu': [1],
    'Tile': [1],
    'TopK': [1],
    'Transpose': [1],
    'Unsqueeze': [1],
    'Upsample': [1],
    'Xor': [1]
}

frontend_opset_version = {
    'ATen': [],
    'Abs': [],
    'Add': [1, 6],
    'Affine': [],
    'And': [1, 6],
    'ArgMax': [1],
    'ArgMin': [1],
    'AveragePool': [1],
    'BatchNormalization': [1, 6],
    'Cast': [1],
    'Ceil': [],
    'Clip': [],
    'Concat': [1, 4],
    'Constant': [],
    'ConstantFill': [],
    'Conv': [1],
    'ConvTranspose': [],
    'Crop': [],
    'DepthToSpace': [],
    'Div': [1, 6],
    'Dropout': [],
    'Elu': [],
    'Equal': [1],
    'Exp': [],
    'FC': [],
    'Flatten': [],
    'Floor': [],
    'GRU': [],
    'GRUUnit': [],
    'Gather': [],
    'Gemm': [],
    'GivenTensorFill': [],
    'GlobalAveragePool': [],
    'GlobalLpPool': [],
    'GlobalMaxPool': [],
    'Greater': [1],
    'HardSigmoid': [],
    'Hardmax': [],
    'Identity': [1],
    'If': [],
    'ImageScaler': [],
    'InstanceNormalization': [],
    'LRN': [],
    'LSTM': [],
    'LeakyRelu': [],
    'Less': [1],
    'Log': [],
    'LogSoftmax': [],
    'Loop': [],
    'LoopIndexTensor': [],
    'LpNormalization': [],
    'LpPool': [],
    'MatMul': [1],
    'Max': [1],
    'MaxPool': [1],
    'MaxRoiPool': [],
    'Mean': [],
    'MeanVarianceNormalization': [],
    'Min': [],
    'Mul': [1, 6],
    'Neg': [],
    'Not': [1],
    'Or': [1],
    'PRelu': [],
    'Pad': [1, 2],
    'ParametricSoftplus': [],
    'Pow': [1],
    'RNN': [],
    'RandomNormal': [1],
    'RandomNormalLike': [],
    'RandomUniform': [1],
    'RandomUniformLike': [],
    'Reciprocal': [1, 6],
    'ReduceL1': [],
    'ReduceL2': [],
    'ReduceLogSum': [],
    'ReduceLogSumExp': [],
    'ReduceMax': [1],
    'ReduceMean': [1],
    'ReduceMin': [1],
    'ReduceProd': [1],
    'ReduceSum': [1],
    'ReduceSumSquare': [],
    'Relu': [1, 6],
    'Reshape': [1, 5],
    'Scale': [],
    'ScaledTanh': [],
    'Selu': [],
    'Shape': [1],
    'Sigmoid': [1, 6],
    'Size': [],
    'Slice': [],
    'Softmax': [1],
    'Softplus': [],
    'Softsign': [],
    'SpaceToDepth': [],
    'Split': [1, 2],
    'Sqrt': [1, 6],
    'Squeeze': [1],
    'Sub': [1, 6],
    'Sum': [],
    'Tanh': [1, 6],
    'ThresholdedRelu': [],
    'Tile': [1],
    'TopK': [],
    'Transpose': [1],
    'Unsqueeze': [],
    'Upsample': [],
    'Xor': [1]
}

frontend_tf_opset_version = {
    'add': [1, 6],
    'arg_max': [1],
    'arg_min': [1],
    'avg_pool': [1],
    'bias_add': [1, 6],
    'cast': [1],
    'concat_v2': [1, 4],
    'conv1_d': [1],
    'conv2_d': [1],
    'conv3_d': [1],
    'equal': [1],
    'fused_batch_norm': [1, 6],
    'greater': [1],
    'identity': [1],
    'less': [1],
    'logical_and': [1, 6],
    'logical_not': [1],
    'logical_or': [1],
    'logical_xor': [1],
    'mat_mul': [1],
    'max': [1],
    'max_pool': [1],
    'maximum': [1],
    'mean': [1],
    'min': [1],
    'mul': [1, 6],
    'pad': [1, 2],
    'pow': [1],
    'prod': [1],
    'random_standard_normal': [1],
    'random_uniform': [1],
    'real_div': [1, 6],
    'reciprocal': [1, 6],
    'relu': [1, 6],
    'reshape': [1, 5],
    'shape': [1],
    'sigmoid': [1, 6],
    'softmax': [1],
    'split_v': [1, 2],
    'sqrt': [1, 6],
    'squeeze': [1],
    'sub': [1, 6],
    'sum': [1],
    'tanh': [1, 6],
    'tile': [1],
    'transpose': [1]
}

==> onnx-tf-1.1.2-py36_0.tar.bz2: Lib/site-packages/onnx_tf/opset_version.py <==
backend_opset_version = {
    'ATen': [],
    'Abs': [1, 6],
    'Acos': [],
    'Add': [1, 6],
    'Affine': [],
    'And': [1],
    'ArgMax': [1],
    'ArgMin': [1],
    'Asin': [],
    'Atan': [],
    'AveragePool': [1, 7],
    'BatchNormalization': [1, 6],
    'Cast': [1],
    'Ceil': [1, 6],
    'Clip': [1, 6],
    'Concat': [1, 4],
    'Constant': [1],
    'ConstantFill': [1],
    'Conv': [1],
    'ConvTranspose': [1],
    'Cos': [],
    'Crop': [],
    'DepthToSpace': [1],
    'Div': [1, 6],
    'Dropout': [1, 6],
    'Elu': [1, 6],
    'Equal': [1],
    'Exp': [1, 6],
    'Flatten': [1],
    'Floor': [1, 6],
    'GRU': [],
    'GRUUnit': [],
    'Gather': [1],
    'Gemm': [1, 6],
    'GivenTensorFill': [],
    'GlobalAveragePool': [1],
    'GlobalLpPool': [1, 2],
    'GlobalMaxPool': [1],
    'Greater': [1],
    'HardSigmoid': [1, 6],
    'Hardmax': [1],
    'Identity': [1],
    'If': [],
    'ImageScaler': [],
    'InstanceNormalization': [],
    'LRN': [1],
    'LSTM': [1],
    'LeakyRelu': [1, 6],
    'Less': [1],
    'Log': [1, 6],
    'LogSoftmax': [1],
    'Loop': [],
    'LoopIndexTensor': [],
    'LpNormalization': [1],
    'LpPool': [],
    'MatMul': [1],
    'Max': [1, 6],
    'MaxPool': [1],
    'MaxRoiPool': [],
    'Mean': [1, 6],
    'MeanVarianceNormalization': [],
    'Min': [1, 6],
    'Mul': [1, 6],
    'Neg': [1, 6],
    'Not': [1],
    'Or': [1],
    'PRelu': [1, 6],
    'Pad': [1, 2],
    'ParametricSoftplus': [],
    'Pow': [1],
    'RNN': [],
    'RandomNormal': [1],
    'RandomNormalLike': [1],
    'RandomUniform': [1],
    'RandomUniformLike': [1],
    'Reciprocal': [1, 6],
    'ReduceL1': [1],
    'ReduceL2': [],
    'ReduceLogSum': [1],
    'ReduceLogSumExp': [1],
    'ReduceMax': [1],
    'ReduceMean': [1],
    'ReduceMin': [1],
    'ReduceProd': [1],
    'ReduceSum': [1],
    'ReduceSumSquare': [1],
    'Relu': [1, 6],
    'Reshape': [1, 5],
    'Scale': [],
    'ScaledTanh': [],
    'Selu': [1, 6],
    'Shape': [1],
    'Sigmoid': [1, 6],
    'Sin': [],
    'Size': [1],
    'Slice': [1],
    'Softmax': [1],
    'Softplus': [1],
    'Softsign': [1],
    'SpaceToDepth': [1],
    'Split': [1, 2],
    'Sqrt': [1, 6],
    'Squeeze': [1],
    'Sub': [1, 6],
    'Sum': [1, 6],
    'Tan': [],
    'Tanh': [1, 6],
    'ThresholdedRelu': [1],
    'Tile': [1],
    'TopK': [1],
    'Transpose': [1],
    'Unsqueeze': [1],
    'Upsample': [1],
    'Xor': [1]
}

frontend_opset_version = {
    'ATen': [],
    'Abs': [],
    'Acos': [],
    'Add': [1, 6],
    'Affine': [],
    'And': [1, 6],
    'ArgMax': [1],
    'ArgMin': [1],
    'Asin': [],
    'Atan': [],
    'AveragePool': [1, 7],
    'BatchNormalization': [1, 6],
    'Cast': [1],
    'Ceil': [1, 6],
    'Clip': [],
    'Concat': [1, 4],
    'Constant': [],
    'ConstantFill': [1],
    'Conv': [1],
    'ConvTranspose': [],
    'Cos': [],
    'Crop': [],
    'DepthToSpace': [],
    'Div': [1, 6],
    'Dropout': [],
    'Elu': [],
    'Equal': [1],
    'Exp': [1, 6],
    'Flatten': [],
    'Floor': [1, 6],
    'GRU': [],
    'GRUUnit': [],
    'Gather': [],
    'Gemm': [],
    'GivenTensorFill': [],
    'GlobalAveragePool': [],
    'GlobalLpPool': [],
    'GlobalMaxPool': [],
    'Greater': [1],
    'HardSigmoid': [],
    'Hardmax': [],
    'Identity': [1],
    'If': [],
    'ImageScaler': [],
    'InstanceNormalization': [],
    'LRN': [],
    'LSTM': [],
    'LeakyRelu': [],
    'Less': [1],
    'Log': [1, 6],
    'LogSoftmax': [1],
    'Loop': [],
    'LoopIndexTensor': [],
    'LpNormalization': [],
    'LpPool': [],
    'MatMul': [1],
    'Max': [1],
    'MaxPool': [1],
    'MaxRoiPool': [],
    'Mean': [],
    'MeanVarianceNormalization': [],
    'Min': [],
    'Mul': [1, 6],
    'Neg': [],
    'Not': [1],
    'Or': [1],
    'PRelu': [],
    'Pad': [1, 2],
    'ParametricSoftplus': [],
    'Pow': [1],
    'RNN': [],
    'RandomNormal': [1],
    'RandomNormalLike': [],
    'RandomUniform': [1],
    'RandomUniformLike': [],
    'Reciprocal': [1, 6],
    'ReduceL1': [],
    'ReduceL2': [],
    'ReduceLogSum': [],
    'ReduceLogSumExp': [],
    'ReduceMax': [1],
    'ReduceMean': [1],
    'ReduceMin': [1],
    'ReduceProd': [1],
    'ReduceSum': [1],
    'ReduceSumSquare': [],
    'Relu': [1, 6],
    'Reshape': [1, 5],
    'Scale': [],
    'ScaledTanh': [],
    'Selu': [],
    'Shape': [1],
    'Sigmoid': [1, 6],
    'Sin': [],
    'Size': [],
    'Slice': [],
    'Softmax': [1],
    'Softplus': [],
    'Softsign': [],
    'SpaceToDepth': [1],
    'Split': [1, 2],
    'Sqrt': [1, 6],
    'Squeeze': [1],
    'Sub': [1, 6],
    'Sum': [],
    'Tan': [],
    'Tanh': [1, 6],
    'ThresholdedRelu': [],
    'Tile': [1],
    'TopK': [],
    'Transpose': [1],
    'Unsqueeze': [],
    'Upsample': [],
    'Xor': [1]
}

frontend_tf_opset_version = {
    'add': [1, 6],
    'arg_max': [1],
    'arg_min': [1],
    'avg_pool': [1, 7],
    'bias_add': [1, 6],
    'cast': [1],
    'ceil': [1, 6],
    'concat_v2': [1, 4],
    'conv1_d': [1],
    'conv2_d': [1],
    'conv3_d': [1],
    'equal': [1],
    'exp': [1, 6],
    'fill': [1],
    'floor': [1, 6],
    'fused_batch_norm': [1, 6],
    'greater': [1],
    'identity': [1],
    'less': [1],
    'log': [1, 6],
    'log_softmax': [1],
    'logical_and': [1, 6],
    'logical_not': [1],
    'logical_or': [1],
    'logical_xor': [1],
    'mat_mul': [1],
    'max': [1],
    'max_pool': [1],
    'maximum': [1],
    'mean': [1],
    'min': [1],
    'mul': [1, 6],
    'pad': [1, 2],
    'pow': [1],
    'prod': [1],
    'random_standard_normal': [1],
    'random_uniform': [1],
    'real_div': [1, 6],
    'reciprocal': [1, 6],
    'relu': [1, 6],
    'reshape': [1, 5],
    'shape': [1],
    'sigmoid': [1, 6],
    'softmax': [1],
    'space_to_depth': [1],
    'split_v': [1, 2],
    'sqrt': [1, 6],
    'squeeze': [1],
    'sub': [1, 6],
    'sum': [1],
    'tanh': [1, 6],
    'tile': [1],
    'transpose': [1]
}
